=====================
Introduction to `rna`
=====================

.. pypi
.. image:: https://img.shields.io/pypi/v/rna.svg
        :target: https://pypi.python.org/pypi/rna

.. ci
    .. image:: https://img.shields.io/travis/dboe/rna.svg
            :target: https://travis-ci.com/dboe/rna
.. image:: https://gitlab.mpcdf.mpg.de/dboe/rna/badges/master/pipeline.svg
    :target: https://gitlab.mpcdf.mpg.de/dboe/rna/commits/master

.. coverage
.. image:: https://gitlab.mpcdf.mpg.de/dboe/rna/badges/master/coverage.svg
    :target: https://gitlab.mpcdf.mpg.de/dboe/rna/commits/master

.. readthedocs
.. image:: https://readthedocs.org/projects/rna_docs/badge/?version=latest
    :target: https://rna_docs.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. pyup crosschecks your dependencies. Github is default, gitlab more complicated: https://pyup.readthedocs.io/en/latest/readme.html#run-your-first-update 
    .. image:: https://pyup.io/repos/github/dboe/rna/shield.svg
         :target: https://pyup.io/repos/github/dboe/rna/
         :alt: Updates

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit


Basic and essential code building blocks of all pythons

Licensed under the ``MIT License``

Resources
---------
* Source code: https://gitlab.mpcdf.mpg.de/dboe/rna
* Documentation: https://rna_docs.readthedocs.io.
* Pypi: https://pypi.python.org/pypi/rna

Features
--------

The following features should be highlighted:

* TODO
